summaryrefslogtreecommitdiff
path: root/usr.sbin/dhcp
diff options
context:
space:
mode:
authorNiels Provos <provos@cvs.openbsd.org>2000-11-10 15:33:16 +0000
committerNiels Provos <provos@cvs.openbsd.org>2000-11-10 15:33:16 +0000
commit5e5c20b4986d64cf4b989750655ce99a581ee745 (patch)
tree454d7edecf7d8c42395d523edcb4da46a285da42 /usr.sbin/dhcp
parentfa37968b43055a44587325acd7d958a96fc4e5a7 (diff)
seperate -> separate, okay aaron@
Diffstat (limited to 'usr.sbin/dhcp')
-rw-r--r--usr.sbin/dhcp/common/dns.c4
-rw-r--r--usr.sbin/dhcp/common/options.c4
-rw-r--r--usr.sbin/dhcp/common/parse.c28
-rw-r--r--usr.sbin/dhcp/includes/cf/sample.h4
-rw-r--r--usr.sbin/dhcp/server/confpars.c4
5 files changed, 22 insertions, 22 deletions
diff --git a/usr.sbin/dhcp/common/dns.c b/usr.sbin/dhcp/common/dns.c
index 1d61b827862..c57b7d0f219 100644
--- a/usr.sbin/dhcp/common/dns.c
+++ b/usr.sbin/dhcp/common/dns.c
@@ -48,7 +48,7 @@
#ifndef lint
static char copyright[] =
-"$Id: dns.c,v 1.1 1998/08/18 03:43:25 deraadt Exp $ Copyright (c) 1997 The Internet Software Consortium. All rights reserved.\n";
+"$Id: dns.c,v 1.2 2000/11/10 15:33:13 provos Exp $ Copyright (c) 1997 The Internet Software Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -123,7 +123,7 @@ static int skipname (label)
}
/* copy_out_name copies out the name appearing at the specified location
- into a string, stored as fields seperated by dots rather than lengths
+ into a string, stored as fields separated by dots rather than lengths
and labels. The length of the label-formatted name is returned. */
static int copy_out_name (base, name, buf)
diff --git a/usr.sbin/dhcp/common/options.c b/usr.sbin/dhcp/common/options.c
index 0935c888328..61064a97673 100644
--- a/usr.sbin/dhcp/common/options.c
+++ b/usr.sbin/dhcp/common/options.c
@@ -42,7 +42,7 @@
#ifndef lint
static char copyright[] =
-"$Id: options.c,v 1.1 1998/08/18 03:43:26 deraadt Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
+"$Id: options.c,v 1.2 2000/11/10 15:33:13 provos Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
#endif /* not lint */
#define DHCP_OPTION_DATA
@@ -152,7 +152,7 @@ void parse_option_buffer (packet, buffer, length)
}
/* cons options into a big buffer, and then split them out into the
- three seperate buffers if needed. This allows us to cons up a set
+ three separate buffers if needed. This allows us to cons up a set
of vendor options using the same routine. */
int cons_options (inpacket, outpacket, options, overload, terminate, bootpp)
diff --git a/usr.sbin/dhcp/includes/cf/sample.h b/usr.sbin/dhcp/includes/cf/sample.h
index 892303b977e..e50d8b17b0e 100644
--- a/usr.sbin/dhcp/includes/cf/sample.h
+++ b/usr.sbin/dhcp/includes/cf/sample.h
@@ -255,13 +255,13 @@ char *strerror PROTO ((int));
/* #define HAVE_SA_LEN */
-/* Every operating system has its own way of seperating lines in a
+/* Every operating system has its own way of separating lines in a
sequential text file. Most modern systems use a single character,
either an ASCII Newline (10) or an ASCII Carriage Return (13).
The most notable exception is MS-DOS (and consequently, Windows),
which uses an ASCII Carriage Return followed by a Newline to
- seperate each line. Fortunately, MS-DOS C compiler libraries
+ separate each line. Fortunately, MS-DOS C compiler libraries
typically hide this from the programmer, returning just a Newline.
Define EOL to be whatever getc() returns for a newline. */
diff --git a/usr.sbin/dhcp/server/confpars.c b/usr.sbin/dhcp/server/confpars.c
index c595680ce6f..14cd539949a 100644
--- a/usr.sbin/dhcp/server/confpars.c
+++ b/usr.sbin/dhcp/server/confpars.c
@@ -42,7 +42,7 @@
#ifndef lint
static char copyright[] =
-"$Id: confpars.c,v 1.1 1998/08/18 03:43:34 deraadt Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
+"$Id: confpars.c,v 1.2 2000/11/10 15:33:14 provos Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -1158,7 +1158,7 @@ struct lease *parse_lease_declaration (cfile)
}
} else {
switch (token) {
- /* Colon-seperated hexadecimal octets... */
+ /* Colon-separated hexadecimal octets... */
case UID:
seenbit = 8;
token = peek_token (&val, cfile);
diff --git a/usr.sbin/dhcp/common/parse.c b/usr.sbin/dhcp/common/parse.c
index 374e2b6e6ec..ca955cfa263 100644
--- a/usr.sbin/dhcp/common/parse.c
+++ b/usr.sbin/dhcp/common/parse.c
@@ -42,7 +42,7 @@
#ifndef lint
static char copyright[] =
-"$Id: parse.c,v 1.1 1998/08/18 03:43:26 deraadt Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
+"$Id: parse.c,v 1.2 2000/11/10 15:33:13 provos Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium. All rights reserved.\n";
#endif /* not lint */
#include "dhcpd.h"
@@ -280,18 +280,18 @@ void parse_lease_time (cfile, timep)
}
/* No BNF for numeric aggregates - that's defined by the caller. What
- this function does is to parse a sequence of numbers seperated by
- the token specified in seperator. If max is zero, any number of
+ this function does is to parse a sequence of numbers separated by
+ the token specified in separator. If max is zero, any number of
numbers will be parsed; otherwise, exactly max numbers are
expected. Base and size tell us how to internalize the numbers
once they've been tokenized. */
unsigned char *parse_numeric_aggregate (cfile, buf,
- max, seperator, base, size)
+ max, separator, base, size)
FILE *cfile;
unsigned char *buf;
int *max;
- int seperator;
+ int separator;
int base;
int size;
{
@@ -311,7 +311,7 @@ unsigned char *parse_numeric_aggregate (cfile, buf,
do {
if (count) {
token = peek_token (&val, cfile);
- if (token != seperator) {
+ if (token != separator) {
if (!*max)
break;
if (token != RBRACE && token != LBRACE)
@@ -519,10 +519,10 @@ TIME parse_date (cfile)
if (tm.tm_year > 1900)
tm.tm_year -= 1900;
/* Slash seperating year from month... */
token = next_token (&val, cfile);
if (token != SLASH) {
- parse_warn ("expected slash seperating year from month.");
+ parse_warn ("expected slash separating year from month.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -538,10 +538,10 @@ TIME parse_date (cfile)
}
tm.tm_mon = atoi (val) - 1;
/* Slash seperating month from day... */
token = next_token (&val, cfile);
if (token != SLASH) {
- parse_warn ("expected slash seperating month from day.");
+ parse_warn ("expected slash separating month from day.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -567,10 +567,10 @@ TIME parse_date (cfile)
}
tm.tm_hour = atoi (val);
/* Colon seperating hour from minute... */
token = next_token (&val, cfile);
if (token != COLON) {
- parse_warn ("expected colon seperating hour from minute.");
+ parse_warn ("expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -586,10 +586,10 @@ TIME parse_date (cfile)
}
tm.tm_min = atoi (val);
/* Colon seperating minute from second... */
token = next_token (&val, cfile);
if (token != COLON) {
- parse_warn ("expected colon seperating hour from minute.");
+ parse_warn ("expected colon separating hour from minute.");
if (token != SEMI)
skip_to_semi (cfile);
return (TIME)0;
@@ -519,10 +519,10 @@ TIME parse_date (cfile)
if (tm.tm_year > 1900)
tm.tm_year -= 1900;
- /* Slash seperating year from month... */
+ /* Slash separating year from month... */
token = next_token (&val, cfile);
if (token != SLASH) {
@@ -538,10 +538,10 @@ TIME parse_date (cfile)
}
tm.tm_mon = atoi (val) - 1;
- /* Slash seperating month from day... */
+ /* Slash separating month from day... */
token = next_token (&val, cfile);
if (token != SLASH) {
@@ -567,10 +567,10 @@ TIME parse_date (cfile)
}
tm.tm_hour = atoi (val);
- /* Colon seperating hour from minute... */
+ /* Colon separating hour from minute... */
token = next_token (&val, cfile);
if (token != COLON) {
@@ -586,10 +586,10 @@ TIME parse_date (cfile)
}
tm.tm_min = atoi (val);
- /* Colon seperating minute from second... */
+ /* Colon separating minute from second... */
token = next_token (&val, cfile);
if (token != COLON) {